.. _github-stats-3-9-2:

GitHub statistics for 3.9.2 (Aug 12, 2024)
==========================================

GitHub statistics for 2024/07/04 (tag: v3.9.1) - 2024/08/12

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 9 issues and merged 45 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/93?closed=1>`__

The following 20 authors contributed 67 commits.

* Adam J. Stewart
* Anthony Lee
* Caitlin Hathaway
* ClarkeAC
* dependabot[bot]
* Elliott Sales de Andrade
* Filippo Balzaretti
* Greg Lucas
* hannah
* Ian Thomas
* Jody Klymak
* Kyle Sunden
* Oscar Gustafsson
* Randolf Scholz
* Refael Ackermann
* Ruth Comer
* Scott Shambaugh
* Sean Smith
* Thomas A Caswell
* Tim Hoffmann

GitHub issues and pull requests:

Pull Requests (45):

* :ghpull:`28687`: BLD: Include MSVCP140 runtime statically
* :ghpull:`28679`: Run delvewheel with path to required msvcp140.dll
* :ghpull:`28695`: Backport PR #27797 on branch v3.9.x (DOC: Use video files for saving animations)
* :ghpull:`28688`: Backport PR #28293 and #28668: Enable 3.13 wheels and bump cibuildwheel
* :ghpull:`27797`: DOC: Use video files for saving animations
* :ghpull:`28692`: Backport PR #28632 on branch v3.9.x (DOC: Tell sphinx-gallery to link mpl_toolkits from our build)
* :ghpull:`28632`: DOC: Tell sphinx-gallery to link mpl_toolkits from our build
* :ghpull:`28668`: Bump the actions group with 2 updates
* :ghpull:`28686`: Backport PR #28682 on branch v3.9.x (Fix warnings from mingw compilers)
* :ghpull:`28682`: Fix warnings from mingw compilers
* :ghpull:`28676`: Backport PR #28577 on branch v3.9.x (Copy all internals from initial Tick to lazy ones)
* :ghpull:`28577`: Copy all internals from initial Tick to lazy ones
* :ghpull:`28674`: Backport PR #28650 on branch v3.9.x (remove out of date todos on animation.py)
* :ghpull:`28650`: remove out of date todos on animation.py
* :ghpull:`28656`: Backport PR #28649 on branch v3.9.x (FIX: improve formatting of image values in cases of singular norms)
* :ghpull:`28665`: Backport PR #28546 on branch v3.9.x (DOC: Clarify/simplify example of multiple images with one colorbar)
* :ghpull:`28649`: FIX: improve formatting of image values in cases of singular norms
* :ghpull:`28635`: BLD: windows wheels
* :ghpull:`28645`: Backport PR #28644 on branch v3.9.x (DOC: Fix matching for version switcher)
* :ghpull:`28640`: Backport PR #28634 on branch v3.9.x (Closed open div tag in color.ColorMap._repr_html_)
* :ghpull:`28634`: Closed open div tag in color.ColorMap._repr_html_
* :ghpull:`28636`: Backport PR #28625 on branch v3.9.x (added typing_extensions.Self to _AxesBase.twinx)
* :ghpull:`28625`: added typing_extensions.Self to _AxesBase.twinx
* :ghpull:`28622`: Backport PR #28621 on branch v3.9.x (TYP: Fix a typo in animation.pyi)
* :ghpull:`28621`: TYP: Fix a typo in animation.pyi
* :ghpull:`28605`: Backport PR #28604 on branch v3.9.x (cycler signature update.)
* :ghpull:`28604`: cycler signature update.
* :ghpull:`28598`: Pin PyQt6 back on Ubuntu 20.04
* :ghpull:`28596`: Backport PR #28518 on branch v3.9.x ([TYP] Fix overload of ``pyplot.subplots``)
* :ghpull:`28518`: [TYP] Fix overload of ``pyplot.subplots``
* :ghpull:`28591`: Backport PR #28580 on branch v3.9.x (Bump actions/attest-build-provenance from 1.3.2 to 1.3.3 in the actions group)
* :ghpull:`28580`: Bump actions/attest-build-provenance from 1.3.2 to 1.3.3 in the actions group
* :ghpull:`28586`: Backport PR #28582 on branch v3.9.x (FIX: make sticky edge tolerance relative to data range)
* :ghpull:`28582`: FIX: make sticky edge tolerance relative to data range
* :ghpull:`28572`: Backport PR #28571 on branch v3.9.x (DOC: Add version directive to hatch parameter in stackplot)
* :ghpull:`28571`: DOC: Add version directive to hatch parameter in stackplot
* :ghpull:`28564`: Backport PR #28534 on branch v3.9.x ([BLD] Fix WSL build warning)
* :ghpull:`28563`: Backport PR #28526 on branch v3.9.x (Bump pypa/cibuildwheel from 2.19.1 to 2.19.2 in the actions group)
* :ghpull:`28534`: [BLD] Fix WSL build warning
* :ghpull:`28526`: Bump pypa/cibuildwheel from 2.19.1 to 2.19.2 in the actions group
* :ghpull:`28552`: Backport PR #28541 on branch v3.9.x (MNT: be more careful about disk I/O failures when writing font cache)
* :ghpull:`28541`: MNT: be more careful about disk I/O failures when writing font cache
* :ghpull:`28524`: Backport PR #28523 on branch v3.9.x (Fix value error when set widget size to zero while using FigureCanvasQT )
* :ghpull:`28523`: Fix value error when set widget size to zero while using FigureCanvasQT
* :ghpull:`28519`: Backport PR #28517 on branch v3.9.x (DOC: better cross referencing for animations)

Issues (9):

* :ghissue:`28551`: [Bug]: Possible issue with Matplotlib 3.9.1 wheel on Windows only
* :ghissue:`28250`: [Doc]: Sphinx gallery links mispointed for Axes3D methods
* :ghissue:`28574`: [Bug]: Nondeterministic behavior with subplot spacing and constrained layout
* :ghissue:`28626`: [Doc]: Remove old TODO's from animation.py
* :ghissue:`28648`: [Bug]: format_image_data on an image of only zeros produces a large number of zeros
* :ghissue:`28624`: [Bug]: Bad type hint in ``_AxesBase.twinx()``
* :ghissue:`28567`: [Bug]: sticky edge related changes for datetime plots
* :ghissue:`28533`: [Doc]: Stackplot hatch functionality has version dependencies
* :ghissue:`28538`: [Bug]: Permission denied when importing matplotlib.pyplot
